@@ -59,6 +59,7 @@ import com.openexchange.folderstorage.Permission;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupService;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.java.Strings;
 import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 
 /**
@@ -112,17 +113,28 @@ public class Invite extends SingleXMLPropertyMixin {
     }
 
     private String getEntityElements(Permission permission) throws OXException {
-        StringBuilder StringBuilder = new StringBuilder();
+        String commonName;
+        String uri;
         if (permission.isGroup()) {
             Group group = CalDAVServiceLookup.getService(GroupService.class).getGroup(factory.getContext(), permission.getEntity());
-            StringBuilder.append("<D:href>/principals/groups/").append(group.getIdentifier())
-                .append("/</D:href><CS:common-name> + ").append(group.getDisplayName()).append("</CS:common-name>");
+            uri = "/principals/groups/" + group.getIdentifier();
+            commonName = " + " + group.getDisplayName();
         } else {
             User user = factory.resolveUser(permission.getEntity());
-            StringBuilder.append("<D:href>/principals/users/").append(user.getLoginInfo())
-                .append("/</D:href><CS:common-name>").append(user.getDisplayName()).append("</CS:common-name>");
+            uri = "/principals/users/" + user.getLoginInfo();
+            commonName = user.getDisplayName();
+            if (Strings.isEmpty(commonName)) {
+                commonName = user.getMail();
+                if (Strings.isEmpty(commonName)) {
+                    commonName = "User " + user.getId();
+                }
+            }
         }
-        return StringBuilder.toString();
+        boolean mailtoPrefix = true; // bug #44264
+        return new StringBuilder()
+            .append("<D:href>").append(mailtoPrefix ? "mailto:" : "").append(uri).append("</D:href>")
+            .append("<CS:common-name>").append(commonName).append("</CS:common-name>")
+        .toString();
     }
 
 }
