@@ -179,8 +179,7 @@ public class CaldavPerformer implements SessionHolder {
         final OXWebdavPutAction oxWebdavPut = new OXWebdavPutAction();
         oxWebdavPut.setSessionHolder(this);
 
-        final OXWebdavMaxUploadSizeAction oxWebdavMaxUploadSize = new OXWebdavMaxUploadSizeAction();
-        oxWebdavMaxUploadSize.setSessionHolder(this);
+        final OXWebdavMaxUploadSizeAction oxWebdavMaxUploadSize = new OXWebdavMaxUploadSizeAction(this);
 
         put = prepare(oxWebdavPut, false, true, new WebdavIfMatchAction(), oxWebdavMaxUploadSize);
         trace = prepare(new WebdavTraceAction(), true, true, new WebdavIfAction(0, false, false));
@@ -290,8 +289,6 @@ public class CaldavPerformer implements SessionHolder {
             actions.get(action).perform(webdavRequest, webdavResponse);
         } catch (final WebdavProtocolException x) {
             resp.setStatus(x.getStatus());
-        } catch (final NullPointerException x) {
-            LOG.error("Null reference detected.", x);
         } finally {
             session.set(null);
         }
