@@ -49,15 +49,20 @@
 
 package com.openexchange.carddav.servlet;
 
+import static org.slf4j.LoggerFactory.getLogger;
 import java.io.IOException;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import com.openexchange.carddav.servlet.CarddavPerformer.Action;
+import com.openexchange.ajax.requesthandler.oauth.OAuthConstants;
+import com.openexchange.carddav.Tools;
+import com.openexchange.carddav.osgi.CarddavActivator;
 import com.openexchange.config.cascade.ComposedConfigProperty;
+import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.login.Interface;
+import com.openexchange.oauth.provider.grant.OAuthGrant;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
@@ -73,13 +78,36 @@ import com.openexchange.tools.webdav.OXServlet;
 public class CardDAV extends OXServlet {
 
 	private static final long serialVersionUID = -6381396333467867154L;
+    private static final LoginCustomizer ALLOW_ASTERISK = new AllowAsteriskAsSeparatorCustomizer();
 
-	private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CardDAV.class);
+	private final ServiceLookup services;
+	private final CarddavPerformer performer;
 
-    private static volatile ServiceLookup services;
+    /**
+     * Initializes a new {@link CardDAV}.
+     *
+     * @param services A service lookup reference
+     * @param performer The CardDAV performer
+     */
+    public CardDAV(ServiceLookup services, CarddavPerformer performer) {
+        super();
+        this.services = services;
+        this.performer = performer;
+    }
 
-    public static void setServiceLookup(ServiceLookup serviceLookup) {
-        services = serviceLookup;
+    @Override
+    protected boolean useCookies() {
+        return false;
+    }
+
+    @Override
+    protected boolean allowOAuthAccess() {
+        return true;
+    }
+
+    @Override
+    protected LoginCustomizer getLoginCustomizer() {
+        return ALLOW_ASTERISK;
     }
 
     @Override
@@ -88,67 +116,67 @@ public class CardDAV extends OXServlet {
     }
 
     @Override
-    protected void doCopy(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doCopy(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.COPY);
     }
 
     @Override
-    protected void doLock(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doLock(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.LOCK);
     }
 
     @Override
-    protected void doMkCol(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doMkCol(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.MKCOL);
     }
 
     @Override
-    protected void doMove(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doMove(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.MOVE);
     }
 
     @Override
-    protected void doOptions(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doOptions(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.OPTIONS);
     }
 
     @Override
-    protected void doPropFind(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doPropFind(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.PROPFIND);
     }
 
     @Override
-    protected void doPropPatch(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doPropPatch(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.PROPPATCH);
     }
 
     @Override
-    protected void doUnLock(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doUnLock(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.UNLOCK);
     }
 
     @Override
-    protected void doDelete(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doDelete(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.DELETE);
     }
 
     @Override
-    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.GET);
     }
 
     @Override
-    protected void doHead(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doHead(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.HEAD);
     }
 
     @Override
-    protected void doPut(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doPut(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.PUT);
     }
 
     @Override
-    protected void doTrace(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void doTrace(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         doIt(req, resp, Action.TRACE);
     }
 
@@ -157,46 +185,62 @@ public class CardDAV extends OXServlet {
         doIt(req, resp, Action.REPORT);
     }
 
-    private void doIt(final HttpServletRequest req, final HttpServletResponse resp, final Action action) throws ServletException, IOException {
-        ServerSession session = null;
+    private void doIt(HttpServletRequest request, HttpServletResponse response, Action action) throws ServletException, IOException {
+        /*
+         * get server session from request & check permissions
+         */
+        ServerSession session = null;;
         try {
-            session = ServerSessionAdapter.valueOf(getSession(req));
-            if (!checkPermission(session)) {
-                resp.setStatus(HttpServletResponse.SC_FORBIDDEN);
-                return;
-            }
-        } catch (final OXException exc) {
-            resp.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
+            session = ServerSessionAdapter.valueOf(getSession(request));
+        } catch (OXException e) {
+            getLogger(CarddavActivator.class).error("Error getting server session from request", e);
+            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
             return;
         }
-        CarddavPerformer.getInstance().doIt(req, resp, action, session);
+        if (null == session || false == checkPermission(request, session)) {
+            response.setStatus(HttpServletResponse.SC_FORBIDDEN);
+            return;
+        }
+        /*
+         * perform the action
+         */
+        performer.doIt(request, response, action, session);
     }
 
-    private boolean checkPermission(ServerSession session) {
-        try {
-            ConfigViewFactory configViewFactory = services.getService(ConfigViewFactory.class);
-            if (null == configViewFactory) {
-                // Unable to check...
-                return false;
-            }
-            ComposedConfigProperty<Boolean> property = configViewFactory.getView(session.getUserId(), session.getContextId()).property("com.openexchange.carddav.enabled", boolean.class);
-            return property.isDefined() && property.get() && session.getUserPermissionBits().hasContact();
-
-        } catch (OXException e) {
+    /**
+     * Gets a value indicating whether CardDAV is enabled for the supplied session.
+     *
+     * @param request the HTTP request
+     * @param session The session to check permissions for
+     * @return <code>true</code> if CardDAV is enabled, <code>false</code>, otherwise
+     */
+    private boolean checkPermission(HttpServletRequest request, ServerSession session) {
+        if (false == session.getUserPermissionBits().hasContact()) {
             return false;
         }
-    }
+        ConfigViewFactory configViewFactory = services.getService(ConfigViewFactory.class);
+        if (null == configViewFactory) {
+            getLogger(CardDAV.class).warn("Unable to access confic cascade, unable to check servlet permissions.");
+            return false;
+        }
+        try {
+            ConfigView configView = configViewFactory.getView(session.getUserId(), session.getContextId());
+            ComposedConfigProperty<Boolean> property = configView.property("com.openexchange.carddav.enabled", boolean.class);
+            if (property.isDefined() && property.get()) {
+                OAuthGrant oAuthGrant = (OAuthGrant) request.getAttribute(OAuthConstants.PARAM_OAUTH_GRANT);
+                if (oAuthGrant == null) {
+                    // basic auth took place
+                    return true;
+                } else {
+                    return oAuthGrant.getScope().has(Tools.OAUTH_SCOPE);
+                }
+            }
+        } catch (OXException e) {
+            getLogger(CardDAV.class).error("Error checking if CardDAV is enabled for user {} in context {}: {}",
+                session.getUserId(), session.getContextId(), e.getMessage(), e);
+        }
 
-    @Override
-    protected boolean useCookies() {
         return false;
     }
 
-    private static final LoginCustomizer ALLOW_ASTERISK = new AllowAsteriskAsSeparatorCustomizer();
-
-    @Override
-    protected LoginCustomizer getLoginCustomizer() {
-        return ALLOW_ASTERISK;
-    }
 }
-
